@@ -104,7 +104,7 @@ function `pprint.pprint()`.
             stream.write('\n%s' % (indent * ' '))
         if i % group == 0 and i % epl != 0:
             stream.write(' ')
-        stream.write(str(int(b)))
+        stream.write(str(b))
 
     if multiline:
         stream.write('\n')
@@ -142,7 +142,7 @@ Allowed values for mode are the strings: `left`, `right`, `both`
     if not isinstance(mode, str):
         raise TypeError("str expected for mode, got '%s'" % type(a).__name__)
     if mode not in ('left', 'right', 'both'):
-        raise ValueError("allowed values 'left', 'right', 'both', got: %r" %
+        raise ValueError("mode must be 'left', 'right' or 'both', got: %r" %
                          mode)
     first = 0
     if mode in ('left', 'both'):
@@ -379,9 +379,9 @@ to being strings.  Symbols may may be any hashable object (such as `None`).
     result = {}
 
     def traverse(nd, prefix=bitarray(0, endian)):
-        if hasattr(nd, 'symbol'):  # leaf
+        try:                    # leaf
             result[nd.symbol] = prefix
-        else:  # parent, so traverse each of the children
+        except AttributeError:  # parent, so traverse each of the children
             traverse(nd.child[0], prefix + bitarray([0]))
             traverse(nd.child[1], prefix + bitarray([1]))
 
